import { useEffect } from 'react'
import { Routes, Route, Navigate } from 'react-router-dom'
import { useAuth } from './hooks/useAuth'
import { useTheme } from './hooks/useTheme'

// Layout Components
import { PublicLayout } from './components/layouts/PublicLayout'
import { ProtectedLayout } from './components/layouts/ProtectedLayout'

// Pages
import { LoginPage } from './pages/auth/LoginPage'
import { DashboardPage } from './pages/dashboard/DashboardPage'
import { CertificatesPage } from './pages/certificates/CertificatesPage'
import { CreateCertificatePage } from './pages/certificates/CreateCertificatePage'
import { PerimetersPage } from './pages/perimeters/PerimetersPage'
import { CreatePerimeterPage } from './pages/perimeters/CreatePerimeterPage'
import { UsersPage } from './pages/users/UsersPage'
import { CreateUserPage } from './pages/users/CreateUserPage'
import { EditUserPasswordPage } from './pages/users/EditUserPasswordPage'
import { NotFoundPage } from './pages/NotFoundPage'

// Components
import { LoadingSpinner } from './components/ui/LoadingSpinner'

function App() {
  const { isAuthenticated, isLoading } = useAuth()
  const { theme } = useTheme()

  useEffect(() => {
    // Apply theme to document
    if (theme === 'dark') {
      document.documentElement.classList.add('dark')
    } else {
      document.documentElement.classList.remove('dark')
    }
  }, [theme])

  if (isLoading) {
    return (
      <div className="min-h-screen flex items-center justify-center">
        <LoadingSpinner size="lg" />
      </div>
    )
  }

  return (
    <Routes>
      {/* Public Routes */}
      <Route path="/login" element={
        !isAuthenticated ? (
          <PublicLayout>
            <LoginPage />
          </PublicLayout>
        ) : (
          <Navigate to="/dashboard" replace />
        )
      } />

      {/* Protected Routes */}
      <Route path="/" element={
        isAuthenticated ? (
          <ProtectedLayout />
        ) : (
          <Navigate to="/login" replace />
        )
      }>
        <Route index element={<Navigate to="/dashboard" replace />} />
        <Route path="dashboard" element={<DashboardPage />} />
        
        <Route path="certificates">
          <Route index element={<CertificatesPage />} />
          <Route path="create" element={<CreateCertificatePage />} />
        </Route>
        
        <Route path="perimeters">
          <Route index element={<PerimetersPage />} />
          <Route path="create" element={<CreatePerimeterPage />} />
        </Route>
        
        <Route path="users">
          <Route index element={<UsersPage />} />
          <Route path="create" element={<CreateUserPage />} />
          <Route path=":id/edit-password" element={<EditUserPasswordPage />} />
        </Route>
      </Route>

      {/* 404 */}
      <Route path="*" element={<NotFoundPage />} />
    </Routes>
  )
}

export default App